export type Events = "destroy";
export type EventsMap = Map<Events, Array<(arg0: Session) => void>>;
export type EventCallback = (session: Session) => any;
export type Session = {
    /**
     * Session id (readonly).
     */
    id: string;
    /**
     * Session data.
     */
    data: Map<string, any>;
    /**
     * Unix timestamp indicating the creation date of the session (readonly).
     */
    createdUnix: number;
    /**
     * Unix timestamp of when the session will expire (readonly).
     */
    expiresAtUnix: number;
    /**
     * Get the seconds remaining before the session expires.
     */
    getRemainingSeconds: GetRemainingSeconds;
    /**
     * Get the seconds remaining before the session expires.
     */
    destroy: Destroy;
    /**
     * Create a new `Response` with the required headers for managing the session.
     */
    response: ResponseCreator;
    /**
     * Add an event listener.
     */
    addEventListener: AddEventListener;
    /**
     * Remove an event listener.
     */
    removeEventListener: RemoveEventListener;
};
export type AddEventListener = (event: Events, callback: EventCallback) => any;
export type RemoveEventListener = (event: Events, callback: EventCallback) => any;
export type Destroy = () => Promise<import("sveltekit-unsafe").Unsafe<void>>;
export type GetRemainingSeconds = () => number;
export type ResponseCreator = (body?: BodyInit | undefined, init?: ResponseInit | undefined) => Response;
